@@ -19,6 +19,6 @@ def codedit(find, replace, namespace=globals()):
 
 #* Codedit modules
 class Codedits():
-    @classmethod
-    def Lambda(self, lambda_symbol):
+    @staticmethod
+    def Lambda(lambda_symbol):
         return codedit(r"{(.*)" + lambda_symbol + r"(.*)}", r"lambda \1: \2")
